@@ -27,6 +27,17 @@ from .planner import (
     plan_batch_generation,
 )
 from .orchestrator import CliAction, execute_cli_actions
+from .status import (
+    CampaignStatusPayload,
+    CampaignStatusReport,
+    CampaignTotals,
+    PlacementStatus,
+    RoutePlacementStatus,
+    RouteStatus,
+    PendingVariant,
+    build_campaign_status,
+    normalize_campaign_status_payload,
+)
 
 __all__ = [
     "CampaignWorkspace",
@@ -53,4 +64,13 @@ __all__ = [
     "plan_batch_generation",
     "CliAction",
     "execute_cli_actions",
+    "CampaignStatusReport",
+    "CampaignTotals",
+    "PlacementStatus",
+    "RoutePlacementStatus",
+    "RouteStatus",
+    "PendingVariant",
+    "build_campaign_status",
+    "CampaignStatusPayload",
+    "normalize_campaign_status_payload",
 ]
